%======================================================================
%                    S E T _ C A S T _ P A R A M S . M 
%                    doc: Mon Apr 20 09:03:09 2015
%                    dlm: Thu May 11 13:51:32 2023
%                    (c) 2015 A.M. Thurnherr
%                    uE-Info: 13 24 NIL 0 0 72 2 2 4 NIL ofnI
%======================================================================

insufficient_backscatter_stns = ...
	[11801 11904 12001 12301 12401 12502 12601 12701 12802 12901 13001 ...
	 13102 13402 13501 13702 14002 14101 14401 14501 14602 14801 14902 ...
	 15301 15502 15601 15802 16301 16501 16601 17101 17302 17401 17501 ...
	 17801 18001 18202];

close all; figure(100);
more off;

%processing_version = 1;									% no SADCP
%processing_version = 2;									% no BT
%processing_version = 3;									% all constraints
%processing_version = 4;									% no SADCP, IMPed
%processing_version = 5;									% no BT, IMPed
%processing_version = 6;									% SADCP only for upper ocean velocities
%processing_version = 7;										% SADCP and BT
processing_version = 8;										% final version (V3 or V6)

final_version 		= 8;

f.res         = sprintf('V%d/%05d',processing_version,stn);
f.checkpoints = sprintf('./checkpoints/%05d',stn);

if processing_version==4 || processing_version==5
	dfextn = '.IMP';
else
	dfextn = '.PD0';
end

f.ladcpdo = sprintf('../Data/PD0/%05d_DL%s',stn,dfextn);
f.ladcpup = sprintf('../Data/PD0/%05d_UL%s',stn,dfextn);

%----------------------------------------------------------------------
% mkSADCP('../Data/SADCP/RR2205/proc/os150nb/contour','../Data/SADCP/SADCP_1.mat');
%	first SADCP processing date 2022-6-14 5:40:14
%	 last SADCP processing date 2022-6-20 2:8:43
% mkSADCP('../Data/SADCP/RR2205_part2/proc/os150nb/contour','../Data/SADCP/SADCP_2.mat');
%	first SADCP processing date 2022-6-21 5:52:10
%	 last SADCP processing date 2022-7-16 15:23:36
%----------------------------------------------------------------------

if stn <= 12701 || stn > 20401
	f.sadcp = '../Data/SADCP/SADCP_1.mat';
elseif stn >= 13102
	f.sadcp = '../Data/SADCP/SADCP_2.mat';
end

f.ctd = sprintf('../Data/CTD/6Hz/%05d.1Hz',stn);
    f.ctd_header_lines      = 50;
    f.ctd_fields_per_line   = 12;
    f.ctd_pressure_field    = 2;
    f.ctd_temperature_field = 3;
    f.ctd_salinity_field    = 6;
    f.ctd_time_field        = 1;
    f.ctd_time_base         = 0;

f.nav = f.ctd;              
    f.nav_header_lines      = f.ctd_header_lines;
    f.nav_fields_per_line   = f.ctd_fields_per_line;
    f.nav_time_field        = f.ctd_time_field;
    f.nav_lat_field         = 11;
    f.nav_lon_field         = 12;
    f.nav_time_base         = f.ctd_time_base;    
    
%----------------------------------------------------------------------

ps.fig3_colormap 	= 1;					% defaults
ps.fig3_err_y_axis 	= 1;
ps.sadcpfac			= 1;
ps.botfac			= 1;
ps.barofac			= 1;
p.saveplot	        = [1:6 9:11 12:14 1];	% first plot is sometimes not 01 (Matlab bug)
p.ctdmaxlag 		= 150;
p.getdepth 			= 2;
p.btrk_ts 			= 40;								% 30 is too little for 002 (this cruise???)

if processing_version==1 || processing_version==4		% disable SADCP constraint for QC
	ps.sadcpfac 	= 0;
end

if processing_version==2 || processing_version==5		% disable BT constraint for QC
	ps.botfac 	= 0;
end

if processing_version==6								% SADCP only for upper-ocean profiles
	ps.botfac 	= 0;
	ps.barofac 	= 0;
end

if processing_version==7								% SADCP/BT only for upper-ocean profiles
	ps.barofac 	= 0;
end

if processing_version==8								% use V3 or V6 depending on QC
	if ismember(stn,insufficient_backscatter_stns)
		p.edit_depths = [1500 9999];
		ps.botfac 	= 0;
		ps.barofac 	= 0;
	end
end

if processing_version == final_version		% make pdf plots (instead of ps)
	p.saveplot_pdf = [1:6 9:11 13:14 1];
	p.saveplot = [];
end

p.ladcp_station     = stn;
p.checkpoints       = [1]; 

p.cruise_id         = 'P2E';
p.whoami            = 'A.M. Thurnherr';
p.name              = sprintf('%s station #%d (V%d)',p.cruise_id,p.ladcp_station,processing_version);
